#!/bin/bash

source "${GITDIR:-`git rev-parse --show-toplevel`}/src/scripts/common.sh"

set -eux

GITDIR=${GITDIR:-`git rev-parse --show-toplevel`}

do_exec cd "$(dirname "$0")"

# Create a directory to hold the generated JSON schemas
do_exec mkdir -p generated

# Generate JSON schemas from the TypeScript models
do_exec npx --yes typescript-json-schema@0.55.0 --yes --aliasRefs --required "**/*.ts" "*" -o generated/all.schemas.json
${GITDIR}/src/scripts/fix_eof.sh generated/all.schemas.json

# Generate Go types from the JSON schemas
QUICKTYPE=quicktype@v23.0.32
GO_PACKAGE=schemas_v2
GO_DIR=${GITDIR}/src/services/goapi/pkg/schemas/v2
do_exec npx --yes ${QUICKTYPE} -s schema -l go --no-maps --no-combine-classes --multi-file-output --package ${GO_PACKAGE} -o ${GO_DIR}/hello generated/all.schemas.json#/definitions/

export GOBIN="${GOBIN:-$HOME/go/bin}"
do_echo "Installing gofumpt if needed..."
if ! gofumpt --version ; then
  do_exec go install mvdan.cc/gofumpt@latest
fi
gofumpt -l -w ${GO_DIR}

# Copy TypeScript files to the frontend
function sync_ts_files {
  # source and destination directories
  local src_dir="$1"
  local dest_dir="$2"

  # create a temporary directory
  local temp_dir=$(mktemp -d)

  do_exec rsync -avm --include='*.ts' --include='*/' --exclude='*' "$src_dir" "$temp_dir"

  # find all .ts files in the temporary directory, append the comment
  do_exec find "$temp_dir" -type f -name "*.ts" -exec sh -c 'echo "// DO NOT EDIT THIS FILE HERE, SEE src/lib/model-schemas/schemas/v2" >> "$1"' _ {} \;

  # use rsync to copy files from the temporary directory to the final directory
  do_exec pushd $temp_dir
  do_exec rsync -avm --include='*.ts' --include='*/' --exclude='*' . "$dest_dir"
  do_exec popd

  do_exec rm -rf "$temp_dir"
}

FRONTEND_DIR=${GITDIR}/src/services/frontend/src/app/third_party_types
do_exec sync_ts_files . ${FRONTEND_DIR}

# Copy the JSON schema to Goapi
GO_API_DIR=${GITDIR}/src/services/goapi/api/schemas/json
do_exec cp -f generated/all.schemas.json ${GO_API_DIR}/ts-generated.schemas.json
do_exec chmod -w ${GO_API_DIR}/ts-generated.schemas.json
